.. include:: ../README.md
   :parser: myst_parser.sphinx_


.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   contributing


.. toctree::
   :maxdepth: 1

   changelog.md


.. toctree::
   :maxdepth: 2
   :caption: Module

   _source/tahrir
